@@ -3,11 +3,11 @@
 # All rights reserved
 __author__ = 'Wu Dong <wudong@eastwu.cn>'
 __title__ = 'pre_request'
-__description__ = 'Deal with request params for Flask and Tornado'
+__description__ = 'Deal with request params for Flask'
 __url__ = 'https://github.com/Eastwu5788/pre-request'
-__version__ = '1.1.0'
+__version__ = '2.0.1'
 __build__ = 0x000001
 __author_email__ = 'wudong@eastwu.cn'
 __license__ = 'MIT License'
-__copyright__ = 'Copyright 2019 Wu Dong'
+__copyright__ = 'Copyright 2020 Wu Dong'
 __cake__ = u'\u2728 \U0001f370 \u2728'
